# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.core import accounts as accounts
    from stripe.params.v2.core._account_close_params import (
        AccountCloseParams as AccountCloseParams,
    )
    from stripe.params.v2.core._account_create_params import (
        AccountCreateParams as AccountCreateParams,
        AccountCreateParamsConfiguration as AccountCreateParamsConfiguration,
        AccountCreateParamsConfigurationCustomer as AccountCreateParamsConfigurationCustomer,
        AccountCreateParamsConfigurationCustomerAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerBilling as AccountCreateParamsConfigurationCustomerBilling,
        AccountCreateParamsConfigurationCustomerBillingInvoice as AccountCreateParamsConfigurationCustomerBillingInvoice,
        AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField as AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountCreateParamsConfigurationCustomerBillingInvoiceRendering as AccountCreateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountCreateParamsConfigurationCustomerCapabilities as AccountCreateParamsConfigurationCustomerCapabilities,
        AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountCreateParamsConfigurationCustomerShipping as AccountCreateParamsConfigurationCustomerShipping,
        AccountCreateParamsConfigurationCustomerShippingAddress as AccountCreateParamsConfigurationCustomerShippingAddress,
        AccountCreateParamsConfigurationMerchant as AccountCreateParamsConfigurationMerchant,
        AccountCreateParamsConfigurationMerchantBacsDebitPayments as AccountCreateParamsConfigurationMerchantBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantBranding as AccountCreateParamsConfigurationMerchantBranding,
        AccountCreateParamsConfigurationMerchantCapabilities as AccountCreateParamsConfigurationMerchantCapabilities,
        AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments as AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments as AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountCreateParamsConfigurationMerchantCardPayments as AccountCreateParamsConfigurationMerchantCardPayments,
        AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountCreateParamsConfigurationMerchantKonbiniPayments as AccountCreateParamsConfigurationMerchantKonbiniPayments,
        AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport as AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport,
        AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours as AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptor as AccountCreateParamsConfigurationMerchantScriptStatementDescriptor,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana as AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana,
        AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji as AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji,
        AccountCreateParamsConfigurationMerchantStatementDescriptor as AccountCreateParamsConfigurationMerchantStatementDescriptor,
        AccountCreateParamsConfigurationMerchantSupport as AccountCreateParamsConfigurationMerchantSupport,
        AccountCreateParamsConfigurationMerchantSupportAddress as AccountCreateParamsConfigurationMerchantSupportAddress,
        AccountCreateParamsConfigurationRecipient as AccountCreateParamsConfigurationRecipient,
        AccountCreateParamsConfigurationRecipientCapabilities as AccountCreateParamsConfigurationRecipientCapabilities,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountCreateParamsDefaults as AccountCreateParamsDefaults,
        AccountCreateParamsDefaultsProfile as AccountCreateParamsDefaultsProfile,
        AccountCreateParamsDefaultsResponsibilities as AccountCreateParamsDefaultsResponsibilities,
        AccountCreateParamsIdentity as AccountCreateParamsIdentity,
        AccountCreateParamsIdentityAttestations as AccountCreateParamsIdentityAttestations,
        AccountCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountCreateParamsIdentityAttestationsOwnershipDeclaration as AccountCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountCreateParamsIdentityAttestationsPersonsProvided as AccountCreateParamsIdentityAttestationsPersonsProvided,
        AccountCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountCreateParamsIdentityAttestationsTermsOfService as AccountCreateParamsIdentityAttestationsTermsOfService,
        AccountCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountCreateParamsIdentityBusinessDetails as AccountCreateParamsIdentityBusinessDetails,
        AccountCreateParamsIdentityBusinessDetailsAdditionalAddress as AccountCreateParamsIdentityBusinessDetailsAdditionalAddress,
        AccountCreateParamsIdentityBusinessDetailsAddress as AccountCreateParamsIdentityBusinessDetailsAddress,
        AccountCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountCreateParamsIdentityBusinessDetailsDocuments as AccountCreateParamsIdentityBusinessDetailsDocuments,
        AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountCreateParamsIdentityBusinessDetailsIdNumber as AccountCreateParamsIdentityBusinessDetailsIdNumber,
        AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountCreateParamsIdentityBusinessDetailsRegistrationDate as AccountCreateParamsIdentityBusinessDetailsRegistrationDate,
        AccountCreateParamsIdentityBusinessDetailsScriptAddresses as AccountCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountCreateParamsIdentityBusinessDetailsScriptNames as AccountCreateParamsIdentityBusinessDetailsScriptNames,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountCreateParamsIdentityIndividual as AccountCreateParamsIdentityIndividual,
        AccountCreateParamsIdentityIndividualAdditionalAddress as AccountCreateParamsIdentityIndividualAdditionalAddress,
        AccountCreateParamsIdentityIndividualAdditionalName as AccountCreateParamsIdentityIndividualAdditionalName,
        AccountCreateParamsIdentityIndividualAddress as AccountCreateParamsIdentityIndividualAddress,
        AccountCreateParamsIdentityIndividualDateOfBirth as AccountCreateParamsIdentityIndividualDateOfBirth,
        AccountCreateParamsIdentityIndividualDocuments as AccountCreateParamsIdentityIndividualDocuments,
        AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountCreateParamsIdentityIndividualDocumentsPassport as AccountCreateParamsIdentityIndividualDocumentsPassport,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountCreateParamsIdentityIndividualDocumentsVisa as AccountCreateParamsIdentityIndividualDocumentsVisa,
        AccountCreateParamsIdentityIndividualIdNumber as AccountCreateParamsIdentityIndividualIdNumber,
        AccountCreateParamsIdentityIndividualRelationship as AccountCreateParamsIdentityIndividualRelationship,
        AccountCreateParamsIdentityIndividualScriptAddresses as AccountCreateParamsIdentityIndividualScriptAddresses,
        AccountCreateParamsIdentityIndividualScriptAddressesKana as AccountCreateParamsIdentityIndividualScriptAddressesKana,
        AccountCreateParamsIdentityIndividualScriptAddressesKanji as AccountCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountCreateParamsIdentityIndividualScriptNames as AccountCreateParamsIdentityIndividualScriptNames,
        AccountCreateParamsIdentityIndividualScriptNamesKana as AccountCreateParamsIdentityIndividualScriptNamesKana,
        AccountCreateParamsIdentityIndividualScriptNamesKanji as AccountCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_link_create_params import (
        AccountLinkCreateParams as AccountLinkCreateParams,
        AccountLinkCreateParamsUseCase as AccountLinkCreateParamsUseCase,
        AccountLinkCreateParamsUseCaseAccountOnboarding as AccountLinkCreateParamsUseCaseAccountOnboarding,
        AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions as AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions,
        AccountLinkCreateParamsUseCaseAccountUpdate as AccountLinkCreateParamsUseCaseAccountUpdate,
        AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions as AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions,
    )
    from stripe.params.v2.core._account_list_params import (
        AccountListParams as AccountListParams,
    )
    from stripe.params.v2.core._account_retrieve_params import (
        AccountRetrieveParams as AccountRetrieveParams,
    )
    from stripe.params.v2.core._account_token_create_params import (
        AccountTokenCreateParams as AccountTokenCreateParams,
        AccountTokenCreateParamsIdentity as AccountTokenCreateParamsIdentity,
        AccountTokenCreateParamsIdentityAttestations as AccountTokenCreateParamsIdentityAttestations,
        AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration as AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration as AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration,
        AccountTokenCreateParamsIdentityAttestationsPersonsProvided as AccountTokenCreateParamsIdentityAttestationsPersonsProvided,
        AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration as AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountTokenCreateParamsIdentityAttestationsTermsOfService as AccountTokenCreateParamsIdentityAttestationsTermsOfService,
        AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount as AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountTokenCreateParamsIdentityBusinessDetails as AccountTokenCreateParamsIdentityBusinessDetails,
        AccountTokenCreateParamsIdentityBusinessDetailsAdditionalAddress as AccountTokenCreateParamsIdentityBusinessDetailsAdditionalAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsAddress as AccountTokenCreateParamsIdentityBusinessDetailsAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue as AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountTokenCreateParamsIdentityBusinessDetailsDocuments as AccountTokenCreateParamsIdentityBusinessDetailsDocuments,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountTokenCreateParamsIdentityBusinessDetailsIdNumber as AccountTokenCreateParamsIdentityBusinessDetailsIdNumber,
        AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate as AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNames as AccountTokenCreateParamsIdentityBusinessDetailsScriptNames,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana as AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji as AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountTokenCreateParamsIdentityIndividual as AccountTokenCreateParamsIdentityIndividual,
        AccountTokenCreateParamsIdentityIndividualAdditionalAddress as AccountTokenCreateParamsIdentityIndividualAdditionalAddress,
        AccountTokenCreateParamsIdentityIndividualAdditionalName as AccountTokenCreateParamsIdentityIndividualAdditionalName,
        AccountTokenCreateParamsIdentityIndividualAddress as AccountTokenCreateParamsIdentityIndividualAddress,
        AccountTokenCreateParamsIdentityIndividualDateOfBirth as AccountTokenCreateParamsIdentityIndividualDateOfBirth,
        AccountTokenCreateParamsIdentityIndividualDocuments as AccountTokenCreateParamsIdentityIndividualDocuments,
        AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountTokenCreateParamsIdentityIndividualDocumentsPassport as AccountTokenCreateParamsIdentityIndividualDocumentsPassport,
        AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification as AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification as AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountTokenCreateParamsIdentityIndividualDocumentsVisa as AccountTokenCreateParamsIdentityIndividualDocumentsVisa,
        AccountTokenCreateParamsIdentityIndividualIdNumber as AccountTokenCreateParamsIdentityIndividualIdNumber,
        AccountTokenCreateParamsIdentityIndividualRelationship as AccountTokenCreateParamsIdentityIndividualRelationship,
        AccountTokenCreateParamsIdentityIndividualScriptAddresses as AccountTokenCreateParamsIdentityIndividualScriptAddresses,
        AccountTokenCreateParamsIdentityIndividualScriptAddressesKana as AccountTokenCreateParamsIdentityIndividualScriptAddressesKana,
        AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji as AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji,
        AccountTokenCreateParamsIdentityIndividualScriptNames as AccountTokenCreateParamsIdentityIndividualScriptNames,
        AccountTokenCreateParamsIdentityIndividualScriptNamesKana as AccountTokenCreateParamsIdentityIndividualScriptNamesKana,
        AccountTokenCreateParamsIdentityIndividualScriptNamesKanji as AccountTokenCreateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._account_token_retrieve_params import (
        AccountTokenRetrieveParams as AccountTokenRetrieveParams,
    )
    from stripe.params.v2.core._account_update_params import (
        AccountUpdateParams as AccountUpdateParams,
        AccountUpdateParamsConfiguration as AccountUpdateParamsConfiguration,
        AccountUpdateParamsConfigurationCustomer as AccountUpdateParamsConfigurationCustomer,
        AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerBilling as AccountUpdateParamsConfigurationCustomerBilling,
        AccountUpdateParamsConfigurationCustomerBillingInvoice as AccountUpdateParamsConfigurationCustomerBillingInvoice,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField as AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField,
        AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering as AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering,
        AccountUpdateParamsConfigurationCustomerCapabilities as AccountUpdateParamsConfigurationCustomerCapabilities,
        AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax as AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax,
        AccountUpdateParamsConfigurationCustomerShipping as AccountUpdateParamsConfigurationCustomerShipping,
        AccountUpdateParamsConfigurationCustomerShippingAddress as AccountUpdateParamsConfigurationCustomerShippingAddress,
        AccountUpdateParamsConfigurationMerchant as AccountUpdateParamsConfigurationMerchant,
        AccountUpdateParamsConfigurationMerchantBacsDebitPayments as AccountUpdateParamsConfigurationMerchantBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantBranding as AccountUpdateParamsConfigurationMerchantBranding,
        AccountUpdateParamsConfigurationMerchantCapabilities as AccountUpdateParamsConfigurationMerchantCapabilities,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments as AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments,
        AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments as AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments,
        AccountUpdateParamsConfigurationMerchantCardPayments as AccountUpdateParamsConfigurationMerchantCardPayments,
        AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn as AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn,
        AccountUpdateParamsConfigurationMerchantKonbiniPayments as AccountUpdateParamsConfigurationMerchantKonbiniPayments,
        AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport as AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport,
        AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours as AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana,
        AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji as AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji,
        AccountUpdateParamsConfigurationMerchantStatementDescriptor as AccountUpdateParamsConfigurationMerchantStatementDescriptor,
        AccountUpdateParamsConfigurationMerchantSupport as AccountUpdateParamsConfigurationMerchantSupport,
        AccountUpdateParamsConfigurationMerchantSupportAddress as AccountUpdateParamsConfigurationMerchantSupportAddress,
        AccountUpdateParamsConfigurationRecipient as AccountUpdateParamsConfigurationRecipient,
        AccountUpdateParamsConfigurationRecipientCapabilities as AccountUpdateParamsConfigurationRecipientCapabilities,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance,
        AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers as AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers,
        AccountUpdateParamsDefaults as AccountUpdateParamsDefaults,
        AccountUpdateParamsDefaultsProfile as AccountUpdateParamsDefaultsProfile,
        AccountUpdateParamsDefaultsResponsibilities as AccountUpdateParamsDefaultsResponsibilities,
        AccountUpdateParamsIdentity as AccountUpdateParamsIdentity,
        AccountUpdateParamsIdentityAttestations as AccountUpdateParamsIdentityAttestations,
        AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration as AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration,
        AccountUpdateParamsIdentityAttestationsOwnershipDeclaration as AccountUpdateParamsIdentityAttestationsOwnershipDeclaration,
        AccountUpdateParamsIdentityAttestationsPersonsProvided as AccountUpdateParamsIdentityAttestationsPersonsProvided,
        AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration as AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration,
        AccountUpdateParamsIdentityAttestationsTermsOfService as AccountUpdateParamsIdentityAttestationsTermsOfService,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount as AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager,
        AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager as AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager,
        AccountUpdateParamsIdentityBusinessDetails as AccountUpdateParamsIdentityBusinessDetails,
        AccountUpdateParamsIdentityBusinessDetailsAdditionalAddress as AccountUpdateParamsIdentityBusinessDetailsAdditionalAddress,
        AccountUpdateParamsIdentityBusinessDetailsAddress as AccountUpdateParamsIdentityBusinessDetailsAddress,
        AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue as AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue,
        AccountUpdateParamsIdentityBusinessDetailsDocuments as AccountUpdateParamsIdentityBusinessDetailsDocuments,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership,
        AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner as AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner,
        AccountUpdateParamsIdentityBusinessDetailsIdNumber as AccountUpdateParamsIdentityBusinessDetailsIdNumber,
        AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue as AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue,
        AccountUpdateParamsIdentityBusinessDetailsRegistrationDate as AccountUpdateParamsIdentityBusinessDetailsRegistrationDate,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddresses as AccountUpdateParamsIdentityBusinessDetailsScriptAddresses,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji,
        AccountUpdateParamsIdentityBusinessDetailsScriptNames as AccountUpdateParamsIdentityBusinessDetailsScriptNames,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana,
        AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji as AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji,
        AccountUpdateParamsIdentityIndividual as AccountUpdateParamsIdentityIndividual,
        AccountUpdateParamsIdentityIndividualAdditionalAddress as AccountUpdateParamsIdentityIndividualAdditionalAddress,
        AccountUpdateParamsIdentityIndividualAdditionalName as AccountUpdateParamsIdentityIndividualAdditionalName,
        AccountUpdateParamsIdentityIndividualAddress as AccountUpdateParamsIdentityIndividualAddress,
        AccountUpdateParamsIdentityIndividualDateOfBirth as AccountUpdateParamsIdentityIndividualDateOfBirth,
        AccountUpdateParamsIdentityIndividualDocuments as AccountUpdateParamsIdentityIndividualDocuments,
        AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization as AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization,
        AccountUpdateParamsIdentityIndividualDocumentsPassport as AccountUpdateParamsIdentityIndividualDocumentsPassport,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification,
        AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack as AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack,
        AccountUpdateParamsIdentityIndividualDocumentsVisa as AccountUpdateParamsIdentityIndividualDocumentsVisa,
        AccountUpdateParamsIdentityIndividualIdNumber as AccountUpdateParamsIdentityIndividualIdNumber,
        AccountUpdateParamsIdentityIndividualRelationship as AccountUpdateParamsIdentityIndividualRelationship,
        AccountUpdateParamsIdentityIndividualScriptAddresses as AccountUpdateParamsIdentityIndividualScriptAddresses,
        AccountUpdateParamsIdentityIndividualScriptAddressesKana as AccountUpdateParamsIdentityIndividualScriptAddressesKana,
        AccountUpdateParamsIdentityIndividualScriptAddressesKanji as AccountUpdateParamsIdentityIndividualScriptAddressesKanji,
        AccountUpdateParamsIdentityIndividualScriptNames as AccountUpdateParamsIdentityIndividualScriptNames,
        AccountUpdateParamsIdentityIndividualScriptNamesKana as AccountUpdateParamsIdentityIndividualScriptNamesKana,
        AccountUpdateParamsIdentityIndividualScriptNamesKanji as AccountUpdateParamsIdentityIndividualScriptNamesKanji,
    )
    from stripe.params.v2.core._event_destination_create_params import (
        EventDestinationCreateParams as EventDestinationCreateParams,
        EventDestinationCreateParamsAmazonEventbridge as EventDestinationCreateParamsAmazonEventbridge,
        EventDestinationCreateParamsAzureEventGrid as EventDestinationCreateParamsAzureEventGrid,
        EventDestinationCreateParamsWebhookEndpoint as EventDestinationCreateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_destination_delete_params import (
        EventDestinationDeleteParams as EventDestinationDeleteParams,
    )
    from stripe.params.v2.core._event_destination_disable_params import (
        EventDestinationDisableParams as EventDestinationDisableParams,
    )
    from stripe.params.v2.core._event_destination_enable_params import (
        EventDestinationEnableParams as EventDestinationEnableParams,
    )
    from stripe.params.v2.core._event_destination_list_params import (
        EventDestinationListParams as EventDestinationListParams,
    )
    from stripe.params.v2.core._event_destination_ping_params import (
        EventDestinationPingParams as EventDestinationPingParams,
    )
    from stripe.params.v2.core._event_destination_retrieve_params import (
        EventDestinationRetrieveParams as EventDestinationRetrieveParams,
    )
    from stripe.params.v2.core._event_destination_update_params import (
        EventDestinationUpdateParams as EventDestinationUpdateParams,
        EventDestinationUpdateParamsWebhookEndpoint as EventDestinationUpdateParamsWebhookEndpoint,
    )
    from stripe.params.v2.core._event_list_params import (
        EventListParams as EventListParams,
        EventListParamsCreated as EventListParamsCreated,
    )
    from stripe.params.v2.core._event_retrieve_params import (
        EventRetrieveParams as EventRetrieveParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "accounts": ("stripe.params.v2.core.accounts", True),
    "AccountCloseParams": (
        "stripe.params.v2.core._account_close_params",
        False,
    ),
    "AccountCreateParams": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfiguration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPayments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaults": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentity": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAdditionalAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_create_params",
        False,
    ),
    "AccountLinkCreateParams": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCase": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboarding": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountOnboardingCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdate": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsUseCaseAccountUpdateCollectionOptions": (
        "stripe.params.v2.core._account_link_create_params",
        False,
    ),
    "AccountListParams": ("stripe.params.v2.core._account_list_params", False),
    "AccountRetrieveParams": (
        "stripe.params.v2.core._account_retrieve_params",
        False,
    ),
    "AccountTokenCreateParams": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentity": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAdditionalAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenCreateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_token_create_params",
        False,
    ),
    "AccountTokenRetrieveParams": (
        "stripe.params.v2.core._account_token_retrieve_params",
        False,
    ),
    "AccountUpdateParams": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfiguration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomer": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBilling": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoice": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceCustomField": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerBillingInvoiceRendering": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShipping": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationCustomerShippingAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchant": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantBranding": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAchDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAcssDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAffirmPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAlmaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAmazonPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBacsDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBancontactPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBlikPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesBoletoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesCashappPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesEpsPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesFpxPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesGrabpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesIdealPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJcbPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKakaoPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKlarnaPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesKrCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesLinkPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMobilepayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMultibancoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesNaverPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesOxxoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesP24Payments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPayByBankPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaycoPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPaynowPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesPromptpayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesRevolutPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSamsungPayPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSepaDebitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSunbitPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesSwishPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesTwintPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCapabilitiesZipPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantCardPaymentsDeclineOn": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPayments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantKonbiniPaymentsSupportHours": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantScriptStatementDescriptorKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantStatementDescriptor": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationMerchantSupportAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipient": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalance": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaults": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsProfile": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsDefaultsResponsibilities": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentity": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestations": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsDirectorshipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsOwnershipDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsPersonsProvided": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsRepresentativeDeclaration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfService": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceAccount": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityAttestationsTermsOfServiceMoneyManager": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetails": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAdditionalAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsAnnualRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyLicense": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistration": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsRegistrationDate": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityBusinessDetailsScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividual": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAdditionalName": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualAddress": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDateOfBirth": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocuments": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsCompanyAuthorization": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPassport": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerification": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualDocumentsVisa": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualIdNumber": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualRelationship": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddresses": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptAddressesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNames": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKana": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "AccountUpdateParamsIdentityIndividualScriptNamesKanji": (
        "stripe.params.v2.core._account_update_params",
        False,
    ),
    "EventDestinationCreateParams": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAmazonEventbridge": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsAzureEventGrid": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationCreateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_create_params",
        False,
    ),
    "EventDestinationDeleteParams": (
        "stripe.params.v2.core._event_destination_delete_params",
        False,
    ),
    "EventDestinationDisableParams": (
        "stripe.params.v2.core._event_destination_disable_params",
        False,
    ),
    "EventDestinationEnableParams": (
        "stripe.params.v2.core._event_destination_enable_params",
        False,
    ),
    "EventDestinationListParams": (
        "stripe.params.v2.core._event_destination_list_params",
        False,
    ),
    "EventDestinationPingParams": (
        "stripe.params.v2.core._event_destination_ping_params",
        False,
    ),
    "EventDestinationRetrieveParams": (
        "stripe.params.v2.core._event_destination_retrieve_params",
        False,
    ),
    "EventDestinationUpdateParams": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventDestinationUpdateParamsWebhookEndpoint": (
        "stripe.params.v2.core._event_destination_update_params",
        False,
    ),
    "EventListParams": ("stripe.params.v2.core._event_list_params", False),
    "EventListParamsCreated": (
        "stripe.params.v2.core._event_list_params",
        False,
    ),
    "EventRetrieveParams": (
        "stripe.params.v2.core._event_retrieve_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()
